@@ -1,52 +1,18 @@
 #include "sdl4gcj/image/Image.h"
 
 #include "sdl4gcj/video/Surface.h"
-#include "sdl4gcj/Version.h"
 #include "sdl4gcj/SDLException.h"
 
 #include <gcj/cni.h>
 #include <java/lang/String.h>
 #include <stdlib.h>
-#include <string.h>
 #include <SDL.h>
 #include <SDL_image.h>
 
 
 using namespace sdl4gcj::image;
-using sdl4gcj::Version;
 using sdl4gcj::video::Surface;
 
-Version*
-Image::compiledVersion()
-{
-	JvInitClass(&Image::class$);
-
-	SDL_version nativeVersion;
-	SDL_IMAGE_VERSION(&nativeVersion);
-
-	Version* compiledVersion = new Version(
-		nativeVersion.major,
-		nativeVersion.minor,
-		nativeVersion.patch);
-
-	return compiledVersion;
-}
-
-Version*
-Image::linkedVersion()
-{
-	JvInitClass(&Image::class$);
-
-	const SDL_version* nativeVersion = IMG_Linked_Version();
-
-	Version* linkedVersion = new Version(
-		nativeVersion->major,
-		nativeVersion->minor,
-		nativeVersion->patch);
-
-	return linkedVersion;
-}
-
 
 Surface *
 Image::load(::java::lang::String* filePath)
