@@ -133,9 +133,11 @@ Surface::blitSurface(Surface* src,
 	jint dx, jint dy)
 {
 	if (this->implementation == NULL) throw createFreedSurfaceException();
+	SDL_Surface* dstImplementation = (SDL_Surface*)this->implementation;
+
 	if (src->implementation == NULL) throw createFreedSurfaceException();
 	SDL_Surface* srcImplementation = (SDL_Surface*)src->implementation;
-	SDL_Surface* dstImplementation = (SDL_Surface*)this->implementation;
+
 	SDL_Rect srect;
 	SDL_Rect drect;
 
@@ -154,9 +156,11 @@ Surface::blitSurface(Surface* src,
 	jint dx, jint dy)
 {
 	if (this->implementation == NULL) throw createFreedSurfaceException();
-	if (src->implementation == NULL) throw createFreedSurfaceException();
 	SDL_Surface* dstImplementation = (SDL_Surface*)this->implementation;
+
+	if (src->implementation == NULL) throw createFreedSurfaceException();
 	SDL_Surface* srcImplementation = (SDL_Surface*)src->implementation;
+
 	SDL_Rect drect;
 
 	drect.x = dx;
@@ -169,9 +173,11 @@ jint
 Surface::blitSurface(Surface* src)
 {
 	if (this->implementation == NULL) throw createFreedSurfaceException();
-	SDL_Surface* srcImplementation = (SDL_Surface*)src->implementation;
 	SDL_Surface* dstImplementation = (SDL_Surface*)this->implementation;
 
+	if (src->implementation == NULL) throw createFreedSurfaceException();
+	SDL_Surface* srcImplementation = (SDL_Surface*)src->implementation;
+
 	int result = SDL_BlitSurface(srcImplementation, NULL, dstImplementation, NULL);
 	return result;
 }
@@ -317,7 +323,10 @@ Surface::convertSurface (PixelFormat* format, jint flags)
 {
 	if (this->implementation == NULL) throw createFreedSurfaceException();
 	SDL_Surface* nativeSurface = (SDL_Surface*)this->implementation;
-	SDL_PixelFormat* nativeFormat = nativeSurface->format;
+
+	if (format == NULL) throw createFreedSurfaceException();
+	if (format->implementation == NULL) throw createFreedSurfaceException();
+	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)format->implementation;
 
 	SDL_Surface* newNativeSurface = SDL_ConvertSurface(nativeSurface, nativeFormat, flags);
 	if (newNativeSurface == NULL) throw new SDLException();
