@@ -1,5 +1,5 @@
 import java.util.Random;
-import sdl4gcj.Sys;
+import sdl4gcj.SDLSystem;
 import sdl4gcj.video.*;
 import sdl4gcj.event.*;
 import sdl4gcj.input.*;
@@ -8,7 +8,7 @@ public class FillTest
 {
 	public static void main(String[] args)
 	{
-		if (Sys.init(Sys.SDL_INIT_VIDEO) != 0)
+		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO) != 0)
 		{
 			System.out.println("Init() fail");
 			System.exit(0);
@@ -40,10 +40,10 @@ public class FillTest
 			int frames = 0;
 			boolean done = false;
 			EventManager event = new EventManager();
-			long totalTicks = Sys.getTicks();
+			long totalTicks = SDLSystem.getTicks();
 			while (!done)
 			{
-				long startTicks = Sys.getTicks();
+				long startTicks = SDLSystem.getTicks();
 				while (event.pollEvent() > 0)
 				{
 					switch (event.type)
@@ -71,7 +71,7 @@ public class FillTest
 				screen.updateRect(x, y, w, h);
 			}
 
-			totalTicks = Sys.getTicks() - totalTicks;
+			totalTicks = SDLSystem.getTicks() - totalTicks;
 			System.out.println(((double)frames * 1000)/totalTicks + " (Frame per Second)");
 		}
 		catch (Exception e)
@@ -80,7 +80,7 @@ public class FillTest
 		}
 		finally
 		{
-			Sys.quit();
+			SDLSystem.quit();
 		}
 	}
 }
