@@ -1,4 +1,4 @@
-import sdl4gcj.Sys;
+import sdl4gcj.SDLSystem;
 import sdl4gcj.video.*;
 import sdl4gcj.event.*;
 import sdl4gcj.input.*;
@@ -8,7 +8,7 @@ public class PixelsTest
 
 	public static void main(String[] args)
 	{
-		if (Sys.init(Sys.SDL_INIT_VIDEO) != 0)
+		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO) != 0)
 		{
 			System.out.println("init fail.");
 			System.exit(0);
@@ -59,6 +59,6 @@ public class PixelsTest
 			}
 		}
 
-		Sys.quit();
+		SDLSystem.quit();
 	}
 }
