@@ -1,4 +1,4 @@
-import sdl4gcj.Sys;
+import sdl4gcj.SDLSystem;
 import sdl4gcj.SDLConstants;
 import sdl4gcj.video.*;
 import sdl4gcj.event.*;
@@ -11,7 +11,7 @@ public class RepeatTest implements SDLConstants
 
 	public static void main(String[] args)
 	{
-		if (Sys.init(SDL_INIT_VIDEO) != 0)
+		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
 		{
 			System.out.println("Init() fail");
 			System.exit(0);
@@ -76,7 +76,7 @@ public class RepeatTest implements SDLConstants
 		}
 		finally
 		{
-			Sys.quit();
+			SDLSystem.quit();
 		}
 	}
 }
