@@ -22,6 +22,26 @@ public class Test implements SDLConstants
 		else
 			System.out.println("SDLSystem.byteOrder() : SDL_BIG_ENDIAN = " + SDLSystem.byteOrder());
 
+		Screen.setCaption("Window Caption", "Icon Caption");
+		System.out.println("windowCaption : '" + Screen.getWindowCaption() + "'");
+		System.out.println("iconCaption   : '" + Screen.getIconCaption() + "'");
+		Screen.setCaption(null, null); // no change
+		System.out.println("windowCaption : '" + Screen.getWindowCaption() + "'");
+		System.out.println("iconCaption   : '" + Screen.getIconCaption() + "'");
+		Screen.setCaption("", ""); // remove caption
+		System.out.println("windowCaption : '" + Screen.getWindowCaption() + "'");
+		System.out.println("iconCaption   : '" + Screen.getIconCaption() + "'");
+
+		Surface icon = Surface.loadBMP("images/icon.bmp");
+
+		byte[] iconMask = new byte[32 * 4];
+		for (int i = 0;i < iconMask.length;i++)
+		{
+			iconMask[i] = (byte)0x0f;
+		}
+
+		Screen.setIcon(icon, iconMask);
+
 		try
 		{
 			Screen screen = Screen.setVideoMode(640, 480, 32, SDL_SWSURFACE|SDL_ANYFORMAT);
@@ -29,7 +49,6 @@ public class Test implements SDLConstants
 
 			int bgPixel = screen.mapRGB(Color.BLACK);
 
-			Surface icon = Surface.loadBMP("images/icon.bmp");
 			icon.setColorKey(SDL_SRCCOLORKEY|SDL_RLEACCEL);
 			icon.displayFormat();
 
@@ -44,6 +63,9 @@ public class Test implements SDLConstants
 			font.draw(screen, "Push 's' key to save screen into memory", 0, 0);
 			font.draw(screen, "Push 'l' key to load from memory", 0, 32);
 			font.draw(screen, "Push 'c' key to clear screen.", 0, 64);
+			font.draw(screen, "Push 'i' key to iconify window.", 0, 96);
+			font.draw(screen, "Push 't' key to toggle fullscreen mode.", 0, 128);
+			font.draw(screen, "Push 'g' key to grab input mode.", 0, 160);
 			screen.updateRect();
 
 			boolean done = false;
@@ -86,6 +108,24 @@ public class Test implements SDLConstants
 							screen.fillRect(bgPixel);
 							screen.updateRect();
 						}
+						else if (event.keydown.sym == SDLK_i)
+						{
+							screen.iconifyWindow();
+							System.out.println("iconifyWindow()");
+						}
+						else if (event.keydown.sym == SDLK_t)
+						{
+							screen.toggleFullScreen();
+							System.out.println("toggleFullScreen()");
+						}
+						else if (event.keydown.sym == SDLK_g)
+						{
+							boolean grabMode = screen.getGrabInputMode();
+							System.out.println("grabInput()");
+							System.out.println("Old grabMode : " + grabMode);
+							grabMode = screen.grabInput(!grabMode);
+							System.out.println("New grabMode : " + grabMode);
+						}
 						break;
 					case SDL_QUIT:
 						done = true;
